function run_demo()

% Run the simulation and evaluate the errors, for different codes
%
% Random binary code
%
% Jinwei Gu
% 2010/2/24


vol = readVTK('horse.vtk');
vol = vol(1:127,:,:);
[nx, ny, nz] = size(vol);

N_test   = 5;
N_method = 5;

%noise_sigma = [0, 0.0001, 0.0005, 0.001, 0.005, 0.01, 0.02, 0.05];
noise_sigma = [0];

 
for in=1:numel(noise_sigma)

    NRMSE_vol = zeros(N_test, N_method);

    filename = sprintf('runtest_rnd_n%g.txt', noise_sigma(in));
    disp(filename);
    fid = fopen(filename, 'wt');
       
    for ntest = 0 : N_test-1
 
        %---- number of measurements
        n_measure = min(2^ntest * 8, nx);

        %---- step 1. generate samples

        %---- Binary Code 0/1 ----         
		S = double(rand(n_measure, nx)<0.5);
                                   
        pimg = zeros(ny,nx,n_measure);
        cimg = zeros(ny,nz,n_measure);
        for i = 1 : n_measure
            pimg(:,:,i) = repmat(S(i,:),[ny,1]);    
            for j = 1:nz;
                a = vol(:,:,j); a = a';
                a = a.*pimg(:,:,i); % single scattering without attenuation
                cimg(:,j,i) = sum(a,2); 
            end
        end
        cimg = cimg + randn(size(cimg))*noise_sigma(in);        
        cimg(cimg<0) = 0;

    %    for i=1:n_measure
    %        f = sprintf('runtest_%d_img_%03d.png', ntest, i);
    %        a = flipud(cimg(:,:,i))/max(cimg(:));
    %        imwrite(a,f);
    %    end

        %---- step 2. solve by different methods ----
    %     method = 0; % ls
    %     method = 1; % nnls
    %     method = 2; % cs, nonnegative
    %     method = 3; % cs, nonnegative, gradient
    %     method = 4; % cs, nonnegative, gradient + data

        for method = 0:N_method-1

            newvol = zeros(nx,ny,nz);
            step = 1;
            tic
            for i = 1:step:ny
                fprintf(1, 'test %d method %d i %d\n', ntest, method, i);
                for j=1:step:nz
                    A = pimg(i,:,:);  A=A(:); A=reshape(A,[nx, n_measure]); A=A';
                    b = cimg(i,j,:);  b=b(:);                   
                    x = solve_cs_1d(A,b,method,3*noise_sigma(in));
                    newvol(:,i,j) = x;
                end
            end
            toc

            err = nrmse(vol(:,1:step:end,1:step:end), newvol(:,1:step:end,1:step:end));
            NRMSE_vol(ntest+1, method+1) = err;

            fprintf('nrmse %g\n', err);
            fprintf(fid, '%.8g ', err);

            filename = sprintf('test_%d_res_method_%d_noise_%g.vtk', ntest, method, noise_sigma(in));
            writeVTK(newvol, filename);
        end
        fprintf(fid, '\n');
    end
    fclose(fid);    
	end
end